@@ -8,6 +8,7 @@ from r3sponse.classes.utils import color, symbol
 from r3sponse.classes import exceptions
 from django.http import JsonResponse
 import json as pypi_json
+import traceback as _traceback_
 
 # the manager class.
 class R3sponse(object):
@@ -393,10 +394,11 @@ class ResponseObject(object):
 			r3sponse.log(error=self["error"], json=json)
 			sys.exit(1)
 		else:
-			#_traceback_.print_exc() 
-			if not traceback:
-				sys.tracebacklimit = -1 ; sys.traceback_limit = -1
-			if error.lower() in ["valueerror"]: raise Exception(self["error"])
+			#if not traceback:
+			#	sys.tracebacklimit = 0
+			#else:
+			#	sys.tracebacklimit = 1
+			if error.lower() in ["valueerror", "value_error"]: raise ValueError(self["error"])
 			else: raise Exception(self["error"])
 	def unpack(self, 
 		# the key / keys / defaults parameter (#1).
@@ -555,14 +557,18 @@ class ResponseObject(object):
 			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {response.__class__}.")
 		return len(self) <= len(response)
 	# support '==' & '!=' operator.
-	def __eq__(self, response):
-		if not isinstance(response, self.__class__):
+	def __eq__(self, dictionary):
+		if isinstance(dictionary, dict):
+			return str(self.sort()) == str(Files.Dictionary(dictionary).sort())
+		elif not isinstance(dictionary, (self.__class__, Dictionary)):
 			return False
-		return len(self) == len(response)
-	def __ne__(self, response):
-		if not isinstance(response, self.__class__):
+		return str(self.sort()) == str(dictionary.sort())
+	def __ne__(self, dictionary):
+		if isinstance(dictionary, dict):
+			return str(self.sort()) !=  str(Files.Dictionary(dictionary).sort())
+		elif not isinstance(dictionary, (self.__class__, Dictionary)):
 			return True
-		return len(self) != len(response)
+		return str(self.sort()) != str(dictionary.sort())
 	# support 'in' operator.
 	def __contains__(self, response):
 		keys = self.keys()
@@ -596,6 +602,9 @@ class ResponseObject(object):
 	# object instance.
 	def instance(self):
 		return "ResponseObject"
+	@property
+	def __name__(self):
+		return self.instance()
 
 # initialized objects.
 r3sponse = R3sponse()
